@@ -823,12 +823,20 @@ def readLinesFile(filename, grab=False):
 def isEmptyFile(filename, grab=False):
     return not any(readLinesFile(filename, grab=grab))
 
-def readFile(filename, tailbyte=None, headbyte=None):
+def readFile(filename, tailbyte=None, headbyte=None, grab=False):
     """
     Прочитать целый файл или вернуть пустую строку.
     tailbyte: прочитать только последнее указанное количество байт
     headbyte: прочитать только первое указанное количество байт
+    grab: отбросить пустые строки и комментарии (#)
     """
+    def grabdata(s):
+        return "\n".join(x for x in s.split("\n")
+                         if not x.startswith("#") and x.strip())
+    if grab:
+        filterfunc = grabdata
+    else:
+        filterfunc = lambda x: x
     try:
         if path.exists(filename):
             with open(filename, 'r') as f:
@@ -837,9 +845,9 @@ def readFile(filename, tailbyte=None, headbyte=None):
                     if seeksize:
                         f.seek(seeksize)
                 if headbyte:
-                    return f.read(headbyte)
+                    return filterfunc(f.read(headbyte))
                 else:
-                    return f.read()
+                    return filterfunc(f.read())
     except (OSError, IOError):
         pass
     return ""
